package com.zfire.jiasm.syncdata.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.zfire.jiasm.syncdata.constant.ServiceCategoryEnum;
import com.zfire.jiasm.syncdata.gree.GreeLogic;
import com.zfire.jiasm.syncdata.helper.GreeResponseHelper;
import com.zfire.jiasm.syncdata.plus.entity.*;
import com.zfire.jiasm.syncdata.plus.service.WorkerServiceCategoryDetailService;
import com.zfire.jiasm.syncdata.plus.service.WorkerServiceCategoryService;
import com.zfire.jiasm.syncdata.request.SignSplb;
import com.zfire.jiasm.syncdata.response.WangdianWxgVos;
import com.zfire.jiasm.syncdata.response.WxgQueryInfo;
import com.zfire.jiasm.syncdata.service.GLPPWXGQueryAddService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;


@Slf4j
@Service
public class GLPPWXGQueryAddServiceImpl implements GLPPWXGQueryAddService {
    String wdqyapi = "/outapp/wxg/list";

    @Resource
    GreeLogic greeLogic;
    @Resource
    WorkerServiceCategoryService workerServiceCategoryService;
    @Resource
    WorkerServiceCategoryDetailService workerServiceCategoryDetailService;




    @Override
    @Transactional(rollbackFor = Exception.class)
    public void wxgCategoryQueryAdd(Map<String,List<Worker>> Worker_Idcards,ItfTblWangdianWxgDownload wxgDownload,
                                    List<WorkerBrandAccount> workerBrandAccounts,
                                    Map<String,List<WorkerServiceCategoryDetail>> workerServiceCategoryDetailMap,
                                    SysDict sysDict,Map<String, List<SysDictRef>> sysDictRefMap) throws Exception {
        Map<String,Object> req = new HashMap<>();
        WangdianWxgVos wvos = new WangdianWxgVos();
        Map<String, List<WorkerServiceCategoryDetail>> wxgCategoryTypeRecs = new HashMap<>();
        List<WorkerServiceCategory> wscList = new ArrayList<>();
        List<WorkerServiceCategoryDetail> wscdList = new ArrayList<>();

        for (WorkerBrandAccount i:workerBrandAccounts){
            // 提取本地商户师傅信息 网点，师傅编号  不存在不处理 修改处已做了处理 这里只新增(前提是找到师傅所在网点信息)
            WorkerBrandAccount workerBrandAccount = getWorkerBrandAccountData(workerBrandAccounts, wxgDownload);
            if (!(i.getBrandWebsitId().equals(wxgDownload.getWdno()) &&
                    i.getBrandWorkerNumber().equals(wxgDownload.getWxgno()))){
                continue;
            }

            // 师傅对应的网点服务类目信息已存在不处理 只做插入
            if (workerServiceCategoryDetailMap.containsKey(workerBrandAccount.getWebsitWorkerId())){
                continue;
            }

            // 参数 获取网点维修工信息
            getParameter(wxgDownload.getWdno(), wxgDownload.getWxgno(), req);
            log.info("req: {}",req);
            // 格力总部查询工程师信息
            GreeResponseHelper response = greeLogic.greePost(wdqyapi, JSONObject.toJSONString(req), 1);
            if (response.getStatus() == 200){
                WxgQueryInfo resultDatax = JSONObject.parseObject(response.getData().toString(), WxgQueryInfo.class);
                // 无信息不处理
                if ( resultDatax.getWangdianWxgVos().size()<1){
                    continue;
                }

                wvos = resultDatax.getWangdianWxgVos().get(0);

                // 提取师傅的服务大类信息 先内存中查询
                if (workerServiceCategoryDetailMap.containsKey(wxgDownload.getSfzen())){
                    wxgCategoryTypeRecs = workerServiceCategoryDetailMap.get(workerBrandAccount.getWebsitWorkerId()).stream().
                            collect(Collectors.groupingBy(WorkerServiceCategoryDetail::getType));
                } else {
                    List<WorkerServiceCategoryDetail> wxgCategoryRecs = workerServiceCategoryDetailService.lambdaQuery()
                            .eq(WorkerServiceCategoryDetail::getWebsitWorkerId, workerBrandAccount.getWebsitWorkerId()).list();

                    // 服务类型 INSTALL=安装 REPAIR=维修  DELIVERY=配送
                    if (CollectionUtils.isNotEmpty(wxgCategoryRecs)){
                        wxgCategoryTypeRecs = wxgCategoryRecs.stream().
                                collect(Collectors.groupingBy(WorkerServiceCategoryDetail::getType));
                    }
                }

                try {
                    // 同步-师傅服务的类目信息 无则插入
                    getServiceCategory(wvos, wscList, wscdList, sysDict, wxgDownload, wxgCategoryTypeRecs, sysDictRefMap);

                    // 新增或修改(师傅服务的类目)
                    addDataCategory(wscList, wscdList);

                    // 清理缓存，把新增的服务类目加到缓存中
                    extractedCaretory(wscList, wscdList, workerServiceCategoryDetailMap, wxgDownload);

                } catch (Exception ex) {
                    log.info("工程师信息同步失败:{}", ex);
                }
            }
        }
    }

    private void extractedCaretory(List<WorkerServiceCategory> wscList, List<WorkerServiceCategoryDetail> wscdList,
                                   Map<String, List<WorkerServiceCategoryDetail>> oldWxgCategoryRecMap, ItfTblWangdianWxgDownload wxg) {
        if (oldWxgCategoryRecMap.containsKey(wxg.getSfzen())){
            oldWxgCategoryRecMap.get(wxg.getSfzen()).addAll(wscdList);
        }

        wscList.clear();
        wscdList.clear();
    }

    public void addDataCategory(List<WorkerServiceCategory> wscList, List<WorkerServiceCategoryDetail> wscdList) {

        // 师傅服务类目新增
        if (wscList.size()>0){
            workerServiceCategoryService.saveBatch(wscList);
        }
        if (wscdList.size()>0){
            workerServiceCategoryDetailService.saveBatch(wscdList);
        }
    }


    private void getServiceCategory(WangdianWxgVos wvos, List<WorkerServiceCategory> wscList, List<WorkerServiceCategoryDetail> wscdList,
                                    SysDict sysDict, ItfTblWangdianWxgDownload wxg,
                                    Map<String,List<WorkerServiceCategoryDetail>> wxgCategoryTypeRecs,
                                    Map<String, List<SysDictRef>> sysDictRefMap) {
        List<String> complete = new ArrayList<>();
        // 先处理商用
        for (SignSplb syitem: wvos.getSySignSplbList()){
            // 扫描每个大类
            for (String s :syitem.getFwlbList()){
                // 师傅服务的大类中查看是否存在 不存在新增
                extracted(wscList, wscdList, complete, sysDict, wxg, wxgCategoryTypeRecs,
                        syitem, s, ServiceCategoryEnum.COMMERCIAL_TYPE.getCode(), sysDictRefMap);
            }
        }
        complete.clear();

        // 处理家用
        for (SignSplb syitem: wvos.getJySignSplbList()){
            // 扫描每个大类
            for (String s :syitem.getFwlbList()){
                // 师傅服务的大类中查看是否存在 不存在新增
                extracted(wscList, wscdList, complete, sysDict, wxg, wxgCategoryTypeRecs,
                        syitem, s,ServiceCategoryEnum.HOME_TYPE.getCode(), sysDictRefMap);
            }
        }
    }

    private void getParameter(String wdno, String wxgno, Map<String, Object> req) {
        req.put("wdno", wdno);
        req.put("wxgno", wxgno);
        req.put("page", 1);
        req.put("size", 20);
        req.put("xsgsshstat", 2);
    }

    private WorkerBrandAccount getWorkerBrandAccountData(List<WorkerBrandAccount> wbarecs, ItfTblWangdianWxgDownload wxg){
        WorkerBrandAccount workerBrandAccount = null;

        for (WorkerBrandAccount wba: wbarecs){
            if (wba.getBrandWebsitId().equals(wxg.getWdno())
                    && wba.getBrandWorkerNumber().equals(wxg.getWxgno())){
                workerBrandAccount = wba;
                break;
            }
        }

        return workerBrandAccount;
    }


    private void extracted(List<WorkerServiceCategory> wscList, List<WorkerServiceCategoryDetail> wscdList,
                           List<String> complete, SysDict sysDict, ItfTblWangdianWxgDownload wxg,
                           Map<String,List<WorkerServiceCategoryDetail>> wxgCategoryTypeRecs, SignSplb syitem,
                           String s, String type,Map<String, List<SysDictRef>> sysDictRefMap) {
        if ( !complete.contains(s + syitem.getSpdl())){
            // 提取品牌商对应的大类信息
            SysDictRef sysDictRef = sysDictRefMap.get(String.valueOf(syitem.getSpdl())).get(0);

            if (s.equals(ServiceCategoryEnum.INSTALL_TYPE.getText())){
                getAddInfo(wscList, wscdList, sysDict, wxg, wxgCategoryTypeRecs,
                        sysDictRef,ServiceCategoryEnum.INSTALL_TYPE.getCode(),type);
            } else if (s.equals(ServiceCategoryEnum.REPAIR_TYPE.getText())){
                getAddInfo(wscList, wscdList, sysDict, wxg, wxgCategoryTypeRecs,
                        sysDictRef,ServiceCategoryEnum.REPAIR_TYPE.getCode(),type);
            } else if (s.equals(ServiceCategoryEnum.DELIVERY_TYPE.getText())){
                getAddInfo(wscList, wscdList, sysDict, wxg, wxgCategoryTypeRecs,
                        sysDictRef,ServiceCategoryEnum.DELIVERY_TYPE.getCode(),type);
            }
            // 新增过的无需再次新增
            complete.add(s + syitem.getSpdl());
        }
    }

    private void getAddInfo(List<WorkerServiceCategory> wscList, List<WorkerServiceCategoryDetail> wscdList, SysDict sysDict,
                            ItfTblWangdianWxgDownload wxg, Map<String, List<WorkerServiceCategoryDetail>> wxgCategoryTypeRecs,
                            SysDictRef sysDictRef, String code, String type) {
        Boolean include = Boolean.FALSE;
        // 看师傅是否已有（服务类型 INSTALL=安装 REPAIR=维修  DELIVERY=配送）对应的大类信息 如有不做任何处理
        if (wxgCategoryTypeRecs !=null && wxgCategoryTypeRecs.size()>0){
            if (wxgCategoryTypeRecs.containsKey(code)){
                for (WorkerServiceCategoryDetail category : wxgCategoryTypeRecs.get(code)){
                    if (category.getMainId().equals(sysDictRef.getDictCode())){
                        include = Boolean.TRUE;
                        break;
                    }
                }
            }
        }

        if (!include){
            // 新增
            // 看 worker_service_category 有无数据，无数据新增
            if (wxgCategoryTypeRecs ==null || wxgCategoryTypeRecs.size()<1 || !wxgCategoryTypeRecs.containsKey(code) ){
                WorkerServiceCategory wsc = new WorkerServiceCategory();
                wsc.setId(IdWorker.getIdStr());
                wsc.setWorkerId(String.valueOf(wxg.getSfzen()));
                wsc.setServiceCategoryId(sysDict.getDictCode());
                wsc.setServiceCategoryName(sysDict.getDictValue());
                wsc.setFlag(type);
                wsc.setType(code);
                wsc.setCreateTime(new Date());
                wscList.add(wsc);

                // WorkerServiceCategoryDetail 新增
                WorkerServiceCategoryDetail wscd = new WorkerServiceCategoryDetail();
                wscd.setId(IdWorker.getIdStr());
                wscd.setWorkerServiceCategoryId(wsc.getId());
                wscd.setWorkerId(String.valueOf(wxg.getSfzen()));
                wscd.setServiceCategoryId(sysDict.getDictCode());
                wscd.setServiceCategoryName(sysDict.getDictValue());
                wscd.setFlag(type);
                wscd.setType(code);
                wscd.setMainId(sysDictRef.getDictCode());
                wscd.setMainName(sysDictRef.getDictValue());
                wscd.setCreateTime(new Date());

                wscdList.add(wscd);

            } else {
                // WorkerServiceCategoryDetail 新增
                WorkerServiceCategoryDetail wscd = new WorkerServiceCategoryDetail();
                wscd.setId(IdWorker.getIdStr());
                wscd.setWorkerServiceCategoryId(wxgCategoryTypeRecs.get(code).get(0).getServiceCategoryId());
                wscd.setWorkerId(String.valueOf(wxg.getSfzen()));
                wscd.setServiceCategoryId(sysDict.getDictCode());
                wscd.setServiceCategoryName(sysDict.getDictValue());
                wscd.setFlag(type);
                wscd.setType(code);
                wscd.setMainId(sysDictRef.getDictCode());
                wscd.setMainName(sysDictRef.getDictValue());
                wscd.setCreateTime(new Date());
                wscdList.add(wscd);
            }
        }
    }
}
